@@ -5,9 +5,9 @@ import importlib
 
 @contextlib.contextmanager
 def cd(path):
-  """A context manager which changes the working directory to the given
+  """
+  A context manager which changes the working directory to the given
   path, and then changes it back to its previous value on exit.
-
   """
   prev_cwd = os.getcwd()
   os.chdir(path)
@@ -17,7 +17,9 @@ def cd(path):
     os.chdir(prev_cwd)
 
 def memoize(f):
-  """ Memoization decorator for a function taking one or more arguments. """
+  """
+  Memoization decorator for a function taking one or more arguments.
+  """
   class memodict(dict):
     def __getitem__(self, *key):
       return dict.__getitem__(self, key)
@@ -30,9 +32,8 @@ def memoize(f):
 
 def load_class(full_class_string):
   """
-  dynamically load a class from a string
+  Dynamically load a class from a string.
   """
-
   class_data = full_class_string.split(".")
   module_path = ".".join(class_data[:-1])
   class_str = class_data[-1]
